@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.4.0"
+    version = "1.4.1"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -125,7 +125,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        # payload = f"{payload} > status: {group.status} \n\n"
+        payload = f"{payload} > status: {group.status} \n\n"
         payload = f"{payload} > 告警次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
@@ -149,9 +149,20 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         # 获取预设的阀值
         counts = self.get_option("warning_counts", project)
-        #  or counts > group.times_seen
-        if int(group.status) != 0 or int(counts) > int(group.times_seen):
-            data = {}
+        #  or int(counts) > int(group.times_seen)
+        if int(group.status) != 0:
+            data = {
+                "msgtype": "markdown",
+                "markdown": {
+                    "title": "Hi",
+                    "text": "Hello!" + '\n\n' + '@' + '@'.join(phone)
+                },
+                "at": {
+                    "atMobiles": notify_user,
+                    "isAtAll": False
+                }
+
+            }
         else:
             data = {
                 "msgtype": "markdown",
